TimingMiddleware

Struct TimingMiddleware 

pub struct TimingMiddleware { /* private fields */ }
Timing middleware: invokes a user-supplied callback with the elapsed duration after each successful response.

Useful for recording latency metrics without coupling to any particular metrics framework.

Example

use std::sync::Arc;
use std::sync::Mutex;
use oxihttp_client::middleware::TimingMiddleware;

let recorded = Arc::new(Mutex::new(Vec::new()));
let r = Arc::clone(&recorded);
let mw = TimingMiddleware::new(move |d| r.lock().expect("lock").push(d));

Implementations

Source

impl TimingMiddleware

pub fn new<F: Fn(Duration) + Send + Sync + 'static>(f: F) -> Self

Create a new TimingMiddleware with the given callback.

The callback receives the wall-clock elapsed time of the full send() call (including redirect/retry overhead).