Module redirect

Module redirect 

Redirect handling policies for the HTTP client.

Enums

RedirectPolicy
Policy controlling how the client handles HTTP redirects.

Functions

is_redirect_status
Returns true if the given status code is a redirect that should be followed.
redirect_method
Determine the method to use after a redirect.
should_preserve_body
Determine whether to preserve the body after a redirect.