Redirect handling policies for the HTTP client.
Enums
- Redirect
Policy - Policy controlling how the client handles HTTP redirects.
Functions
- is_
redirect_ status - Returns
trueif the given status code is a redirect that should be followed. - redirect_
method - Determine the method to use after a redirect.
- should_
preserve_ body - Determine whether to preserve the body after a redirect.